@@ -7,6 +7,9 @@ types: list[str] = [
     "AWS::ACMPCA::CertificateAuthority",
     "AWS::ACMPCA::CertificateAuthorityActivation",
     "AWS::ACMPCA::Permission",
+    "AWS::APS::RuleGroupsNamespace",
+    "AWS::APS::Scraper",
+    "AWS::APS::Workspace",
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration",
     "AWS::AccessAnalyzer::Analyzer",
@@ -46,6 +49,7 @@ types: list[str] = [
     "AWS::ApiGatewayV2::Model",
     "AWS::ApiGatewayV2::Route",
     "AWS::ApiGatewayV2::RouteResponse",
+    "AWS::ApiGatewayV2::RoutingRule",
     "AWS::ApiGatewayV2::Stage",
     "AWS::ApiGatewayV2::VpcLink",
     "AWS::AppConfig::Application",
@@ -270,7 +274,6 @@ types: list[str] = [
     "AWS::DataSync::LocationObjectStorage",
     "AWS::DataSync::LocationS3",
     "AWS::DataSync::LocationSMB",
-    "AWS::DataSync::StorageSystem",
     "AWS::DataSync::Task",
     "AWS::Detective::Graph",
     "AWS::Detective::MemberInvitation",
@@ -377,6 +380,7 @@ types: list[str] = [
     "AWS::EC2::VolumeAttachment",
     "AWS::ECR::PullThroughCacheRule",
     "AWS::ECR::RegistryPolicy",
+    "AWS::ECR::RegistryScanningConfiguration",
     "AWS::ECR::ReplicationConfiguration",
     "AWS::ECR::Repository",
     "AWS::ECR::RepositoryCreationTemplate",
@@ -408,6 +412,7 @@ types: list[str] = [
     "AWS::EMRContainers::VirtualCluster",
     "AWS::EMRServerless::Application",
     "AWS::ElastiCache::CacheCluster",
+    "AWS::ElastiCache::GlobalReplicationGroup",
     "AWS::ElastiCache::ParameterGroup",
     "AWS::ElastiCache::ReplicationGroup",
     "AWS::ElastiCache::SecurityGroup",
@@ -429,6 +434,11 @@ types: list[str] = [
     "AWS::ElasticLoadBalancingV2::TrustStore",
     "AWS::ElasticLoadBalancingV2::TrustStoreRevocation",
     "AWS::Elasticsearch::Domain",
+    "AWS::EntityResolution::IdMappingWorkflow",
+    "AWS::EntityResolution::IdNamespace",
+    "AWS::EntityResolution::MatchingWorkflow",
+    "AWS::EntityResolution::PolicyStatement",
+    "AWS::EntityResolution::SchemaMapping",
     "AWS::EventSchemas::Discoverer",
     "AWS::EventSchemas::Registry",
     "AWS::EventSchemas::RegistryPolicy",
@@ -603,6 +613,7 @@ types: list[str] = [
     "AWS::NetworkFirewall::LoggingConfiguration",
     "AWS::NetworkFirewall::RuleGroup",
     "AWS::NetworkFirewall::TLSInspectionConfiguration",
+    "AWS::NetworkFirewall::VpcEndpointAssociation",
     "AWS::NetworkManager::ConnectAttachment",
     "AWS::NetworkManager::ConnectPeer",
     "AWS::NetworkManager::CoreNetwork",
@@ -716,12 +727,17 @@ types: list[str] = [
     "AWS::S3::AccessPoint",
     "AWS::S3::Bucket",
     "AWS::S3::BucketPolicy",
+    "AWS::S3::MultiRegionAccessPoint",
+    "AWS::S3::MultiRegionAccessPointPolicy",
     "AWS::S3ObjectLambda::AccessPoint",
     "AWS::S3ObjectLambda::AccessPointPolicy",
     "AWS::S3Outposts::AccessPoint",
     "AWS::S3Outposts::Bucket",
     "AWS::S3Outposts::BucketPolicy",
     "AWS::S3Outposts::Endpoint",
+    "AWS::S3Tables::Namespace",
+    "AWS::S3Tables::TableBucket",
+    "AWS::S3Tables::TableBucketPolicy",
     "AWS::SDB::Domain",
     "AWS::SES::ConfigurationSet",
     "AWS::SES::ConfigurationSetEventDestination",
@@ -784,8 +800,10 @@ types: list[str] = [
     "AWS::SecretsManager::Secret",
     "AWS::SecretsManager::SecretTargetAttachment",
     "AWS::SecurityHub::AutomationRule",
+    "AWS::SecurityHub::AutomationRuleV2",
     "AWS::SecurityHub::DelegatedAdmin",
     "AWS::SecurityHub::Hub",
+    "AWS::SecurityHub::HubV2",
     "AWS::SecurityHub::Insight",
     "AWS::SecurityHub::OrganizationConfiguration",
     "AWS::SecurityHub::ProductSubscription",
@@ -879,6 +897,9 @@ types: list[str] = [
     "AWS::WAFv2::WebACL",
     "AWS::WAFv2::WebACLAssociation",
     "AWS::WorkSpaces::Workspace",
+    "AWS::WorkspacesInstances::Volume",
+    "AWS::WorkspacesInstances::VolumeAssociation",
+    "AWS::WorkspacesInstances::WorkspaceInstance",
     "AWS::XRay::Group",
     "AWS::XRay::ResourcePolicy",
     "AWS::XRay::SamplingRule",
@@ -918,15 +939,18 @@ cached: list[str] = [
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
     "aws-apigateway-vpclink.json",
+    "aws-apigatewayv2-api.json",
     "aws-apigatewayv2-apigatewaymanagedoverrides.json",
     "aws-apigatewayv2-apimapping.json",
     "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
+    "aws-apigatewayv2-domainname.json",
     "aws-apigatewayv2-integration.json",
     "aws-apigatewayv2-integrationresponse.json",
     "aws-apigatewayv2-model.json",
     "aws-apigatewayv2-route.json",
     "aws-apigatewayv2-routeresponse.json",
+    "aws-apigatewayv2-routingrule.json",
     "aws-apigatewayv2-stage.json",
     "aws-apigatewayv2-vpclink.json",
     "aws-appconfig-application.json",
@@ -966,6 +990,9 @@ cached: list[str] = [
     "aws-appsync-graphqlschema.json",
     "aws-appsync-resolver.json",
     "aws-appsync-sourceapiassociation.json",
+    "aws-aps-rulegroupsnamespace.json",
+    "aws-aps-scraper.json",
+    "aws-aps-workspace.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
     "aws-athena-datacatalog.json",
@@ -995,6 +1022,8 @@ cached: list[str] = [
     "aws-cassandra-keyspace.json",
     "aws-cassandra-table.json",
     "aws-cassandra-type.json",
+    "aws-ce-anomalymonitor.json",
+    "aws-ce-anomalysubscription.json",
     "aws-certificatemanager-account.json",
     "aws-certificatemanager-certificate.json",
     "aws-chatbot-microsoftteamschannelconfiguration.json",
@@ -1022,7 +1051,6 @@ cached: list[str] = [
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
     "aws-cloudfront-connectiongroup.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
-    "aws-cloudfront-distribution.json",
     "aws-cloudfront-distributiontenant.json",
     "aws-cloudfront-function.json",
     "aws-cloudfront-keygroup.json",
@@ -1045,6 +1073,7 @@ cached: list[str] = [
     "aws-cloudwatch-dashboard.json",
     "aws-cloudwatch-insightrule.json",
     "aws-cloudwatch-metricstream.json",
+    "aws-codebuild-project.json",
     "aws-codebuild-reportgroup.json",
     "aws-codebuild-sourcecredential.json",
     "aws-codedeploy-application.json",
@@ -1130,7 +1159,6 @@ cached: list[str] = [
     "aws-datasync-locationobjectstorage.json",
     "aws-datasync-locations3.json",
     "aws-datasync-locationsmb.json",
-    "aws-datasync-storagesystem.json",
     "aws-datasync-task.json",
     "aws-detective-graph.json",
     "aws-detective-memberinvitation.json",
@@ -1243,6 +1271,7 @@ cached: list[str] = [
     "aws-ec2-vpngatewayroutepropagation.json",
     "aws-ecr-pullthroughcacherule.json",
     "aws-ecr-registrypolicy.json",
+    "aws-ecr-registryscanningconfiguration.json",
     "aws-ecr-replicationconfiguration.json",
     "aws-ecr-repository.json",
     "aws-ecr-repositorycreationtemplate.json",
@@ -1264,6 +1293,7 @@ cached: list[str] = [
     "aws-eks-nodegroup.json",
     "aws-eks-podidentityassociation.json",
     "aws-elasticache-cachecluster.json",
+    "aws-elasticache-globalreplicationgroup.json",
     "aws-elasticache-parametergroup.json",
     "aws-elasticache-replicationgroup.json",
     "aws-elasticache-securitygroup.json",
@@ -1295,6 +1325,11 @@ cached: list[str] = [
     "aws-emr-walworkspace.json",
     "aws-emrcontainers-virtualcluster.json",
     "aws-emrserverless-application.json",
+    "aws-entityresolution-idmappingworkflow.json",
+    "aws-entityresolution-idnamespace.json",
+    "aws-entityresolution-matchingworkflow.json",
+    "aws-entityresolution-policystatement.json",
+    "aws-entityresolution-schemamapping.json",
     "aws-events-apidestination.json",
     "aws-events-archive.json",
     "aws-events-connection.json",
@@ -1308,6 +1343,7 @@ cached: list[str] = [
     "aws-fis-experimenttemplate.json",
     "aws-fis-targetaccountconfiguration.json",
     "aws-fms-notificationchannel.json",
+    "aws-fms-policy.json",
     "aws-fms-resourceset.json",
     "aws-fsx-datarepositoryassociation.json",
     "aws-fsx-filesystem.json",
@@ -1378,10 +1414,11 @@ cached: list[str] = [
     "aws-inspectorv2-cisscanconfiguration.json",
     "aws-inspectorv2-filter.json",
     "aws-internetmonitor-monitor.json",
+    "aws-iot-thingprincipalattachment.json",
     "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
+    "aws-kinesis-streamconsumer.json",
     "aws-kinesisanalyticsv2-application.json",
-    "aws-kinesisfirehose-deliverystream.json",
     "aws-kms-alias.json",
     "aws-kms-key.json",
     "aws-kms-replicakey.json",
@@ -1401,6 +1438,7 @@ cached: list[str] = [
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
     "aws-lambda-url.json",
+    "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
     "aws-lex-bot.json",
     "aws-lex-botalias.json",
@@ -1412,12 +1450,12 @@ cached: list[str] = [
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
     "aws-logs-loganomalydetector.json",
+    "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
     "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
     "aws-logs-subscriptionfilter.json",
-    "aws-logs-transformer.json",
     "aws-m2-application.json",
     "aws-m2-deployment.json",
     "aws-m2-environment.json",
@@ -1446,14 +1484,15 @@ cached: list[str] = [
     "aws-mwaa-environment.json",
     "aws-neptune-dbcluster.json",
     "aws-neptune-dbclusterparametergroup.json",
+    "aws-neptune-dbinstance.json",
     "aws-neptune-dbparametergroup.json",
     "aws-neptune-dbsubnetgroup.json",
     "aws-neptune-eventsubscription.json",
     "aws-networkfirewall-firewall.json",
     "aws-networkfirewall-firewallpolicy.json",
-    "aws-networkfirewall-loggingconfiguration.json",
     "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
+    "aws-networkfirewall-vpcendpointassociation.json",
     "aws-networkmanager-connectattachment.json",
     "aws-networkmanager-connectpeer.json",
     "aws-networkmanager-corenetwork.json",
@@ -1549,11 +1588,9 @@ cached: list[str] = [
     "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
     "aws-route53resolver-outpostresolver.json",
-    "aws-route53resolver-resolverconfig.json",
     "aws-route53resolver-resolverdnssecconfig.json",
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
-    "aws-route53resolver-resolverruleassociation.json",
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
@@ -1561,12 +1598,17 @@ cached: list[str] = [
     "aws-s3-accesspoint.json",
     "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
+    "aws-s3-multiregionaccesspoint.json",
+    "aws-s3-multiregionaccesspointpolicy.json",
     "aws-s3objectlambda-accesspoint.json",
     "aws-s3objectlambda-accesspointpolicy.json",
     "aws-s3outposts-accesspoint.json",
     "aws-s3outposts-bucket.json",
     "aws-s3outposts-bucketpolicy.json",
     "aws-s3outposts-endpoint.json",
+    "aws-s3tables-namespace.json",
+    "aws-s3tables-tablebucket.json",
+    "aws-s3tables-tablebucketpolicy.json",
     "aws-sagemaker-app.json",
     "aws-sagemaker-appimageconfig.json",
     "aws-sagemaker-coderepository.json",
@@ -1597,8 +1639,10 @@ cached: list[str] = [
     "aws-secretsmanager-secret.json",
     "aws-secretsmanager-secrettargetattachment.json",
     "aws-securityhub-automationrule.json",
+    "aws-securityhub-automationrulev2.json",
     "aws-securityhub-delegatedadmin.json",
     "aws-securityhub-hub.json",
+    "aws-securityhub-hubv2.json",
     "aws-securityhub-insight.json",
     "aws-securityhub-organizationconfiguration.json",
     "aws-securityhub-productsubscription.json",
@@ -1682,6 +1726,9 @@ cached: list[str] = [
     "aws-voiceid-domain.json",
     "aws-vpclattice-accesslogsubscription.json",
     "aws-vpclattice-authpolicy.json",
+    "aws-vpclattice-listener.json",
+    "aws-vpclattice-resourceconfiguration.json",
+    "aws-vpclattice-resourcegateway.json",
     "aws-vpclattice-resourcepolicy.json",
     "aws-vpclattice-rule.json",
     "aws-vpclattice-service.json",
@@ -1700,8 +1747,13 @@ cached: list[str] = [
     "aws-wafv2-ipset.json",
     "aws-wafv2-loggingconfiguration.json",
     "aws-wafv2-regexpatternset.json",
+    "aws-wafv2-rulegroup.json",
+    "aws-wafv2-webacl.json",
     "aws-wafv2-webaclassociation.json",
     "aws-workspaces-workspace.json",
+    "aws-workspacesinstances-volume.json",
+    "aws-workspacesinstances-volumeassociation.json",
+    "aws-workspacesinstances-workspaceinstance.json",
     "aws-xray-group.json",
     "aws-xray-resourcepolicy.json",
     "aws-xray-samplingrule.json",
