@@ -6,6 +6,10 @@ types: list[str] = [
     "AWS::ACMPCA::CertificateAuthority",
     "AWS::ACMPCA::CertificateAuthorityActivation",
     "AWS::ACMPCA::Permission",
+    "AWS::AIOps::InvestigationGroup",
+    "AWS::APS::RuleGroupsNamespace",
+    "AWS::APS::Scraper",
+    "AWS::APS::Workspace",
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration",
     "AWS::AccessAnalyzer::Analyzer",
@@ -48,6 +52,7 @@ types: list[str] = [
     "AWS::ApiGatewayV2::Model",
     "AWS::ApiGatewayV2::Route",
     "AWS::ApiGatewayV2::RouteResponse",
+    "AWS::ApiGatewayV2::RoutingRule",
     "AWS::ApiGatewayV2::Stage",
     "AWS::ApiGatewayV2::VpcLink",
     "AWS::AppConfig::Application",
@@ -237,7 +242,6 @@ types: list[str] = [
     "AWS::DataSync::LocationObjectStorage",
     "AWS::DataSync::LocationS3",
     "AWS::DataSync::LocationSMB",
-    "AWS::DataSync::StorageSystem",
     "AWS::DataSync::Task",
     "AWS::Detective::Graph",
     "AWS::Detective::MemberInvitation",
@@ -416,6 +420,7 @@ types: list[str] = [
     "AWS::FMS::ResourceSet",
     "AWS::FSx::DataRepositoryAssociation",
     "AWS::FSx::FileSystem",
+    "AWS::FSx::S3AccessPointAttachment",
     "AWS::FSx::Snapshot",
     "AWS::FSx::StorageVirtualMachine",
     "AWS::FSx::Volume",
@@ -596,6 +601,7 @@ types: list[str] = [
     "AWS::NetworkFirewall::LoggingConfiguration",
     "AWS::NetworkFirewall::RuleGroup",
     "AWS::NetworkFirewall::TLSInspectionConfiguration",
+    "AWS::NetworkFirewall::VpcEndpointAssociation",
     "AWS::NetworkManager::CustomerGatewayAssociation",
     "AWS::NetworkManager::Device",
     "AWS::NetworkManager::GlobalNetwork",
@@ -612,6 +618,7 @@ types: list[str] = [
     "AWS::OpenSearchServerless::SecurityConfig",
     "AWS::OpenSearchServerless::SecurityPolicy",
     "AWS::OpenSearchServerless::VpcEndpoint",
+    "AWS::OpenSearchService::Application",
     "AWS::OpenSearchService::Domain",
     "AWS::OpsWorks::App",
     "AWS::OpsWorks::ElasticLoadBalancerAttachment",
@@ -663,6 +670,7 @@ types: list[str] = [
     "AWS::Redshift::Integration",
     "AWS::Redshift::ScheduledAction",
     "AWS::RedshiftServerless::Namespace",
+    "AWS::RedshiftServerless::Snapshot",
     "AWS::RedshiftServerless::Workgroup",
     "AWS::ResilienceHub::App",
     "AWS::ResilienceHub::ResiliencyPolicy",
@@ -701,12 +709,17 @@ types: list[str] = [
     "AWS::S3::AccessPoint",
     "AWS::S3::Bucket",
     "AWS::S3::BucketPolicy",
+    "AWS::S3::MultiRegionAccessPoint",
+    "AWS::S3::MultiRegionAccessPointPolicy",
     "AWS::S3ObjectLambda::AccessPoint",
     "AWS::S3ObjectLambda::AccessPointPolicy",
     "AWS::S3Outposts::AccessPoint",
     "AWS::S3Outposts::Bucket",
     "AWS::S3Outposts::BucketPolicy",
     "AWS::S3Outposts::Endpoint",
+    "AWS::S3Tables::Namespace",
+    "AWS::S3Tables::TableBucket",
+    "AWS::S3Tables::TableBucketPolicy",
     "AWS::SDB::Domain",
     "AWS::SNS::Subscription",
     "AWS::SNS::Topic",
@@ -764,8 +777,10 @@ types: list[str] = [
     "AWS::SecretsManager::Secret",
     "AWS::SecretsManager::SecretTargetAttachment",
     "AWS::SecurityHub::AutomationRule",
+    "AWS::SecurityHub::AutomationRuleV2",
     "AWS::SecurityHub::DelegatedAdmin",
     "AWS::SecurityHub::Hub",
+    "AWS::SecurityHub::HubV2",
     "AWS::SecurityHub::Insight",
     "AWS::SecurityHub::OrganizationConfiguration",
     "AWS::SecurityHub::ProductSubscription",
@@ -872,6 +887,7 @@ cached: list[str] = [
     "aws-acmpca-certificateauthority.json",
     "aws-acmpca-certificateauthorityactivation.json",
     "aws-acmpca-permission.json",
+    "aws-aiops-investigationgroup.json",
     "aws-amazonmq-broker.json",
     "aws-amazonmq-configuration.json",
     "aws-amplify-app.json",
@@ -910,6 +926,7 @@ cached: list[str] = [
     "aws-apigatewayv2-model.json",
     "aws-apigatewayv2-route.json",
     "aws-apigatewayv2-routeresponse.json",
+    "aws-apigatewayv2-routingrule.json",
     "aws-apigatewayv2-stage.json",
     "aws-apigatewayv2-vpclink.json",
     "aws-appconfig-application.json",
@@ -944,6 +961,9 @@ cached: list[str] = [
     "aws-appsync-graphqlschema.json",
     "aws-appsync-resolver.json",
     "aws-appsync-sourceapiassociation.json",
+    "aws-aps-rulegroupsnamespace.json",
+    "aws-aps-scraper.json",
+    "aws-aps-workspace.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
     "aws-athena-datacatalog.json",
@@ -1004,7 +1024,6 @@ cached: list[str] = [
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
     "aws-cloudfront-connectiongroup.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
-    "aws-cloudfront-distribution.json",
     "aws-cloudfront-distributiontenant.json",
     "aws-cloudfront-function.json",
     "aws-cloudfront-keygroup.json",
@@ -1027,6 +1046,7 @@ cached: list[str] = [
     "aws-cloudwatch-dashboard.json",
     "aws-cloudwatch-insightrule.json",
     "aws-cloudwatch-metricstream.json",
+    "aws-codebuild-project.json",
     "aws-codebuild-reportgroup.json",
     "aws-codebuild-sourcecredential.json",
     "aws-codecommit-repository.json",
@@ -1083,7 +1103,6 @@ cached: list[str] = [
     "aws-datasync-locationobjectstorage.json",
     "aws-datasync-locations3.json",
     "aws-datasync-locationsmb.json",
-    "aws-datasync-storagesystem.json",
     "aws-datasync-task.json",
     "aws-detective-graph.json",
     "aws-detective-memberinvitation.json",
@@ -1180,6 +1199,7 @@ cached: list[str] = [
     "aws-ec2-transitgatewayroutetableassociation.json",
     "aws-ec2-transitgatewayroutetablepropagation.json",
     "aws-ec2-transitgatewayvpcattachment.json",
+    "aws-ec2-volume.json",
     "aws-ec2-volumeattachment.json",
     "aws-ec2-vpc.json",
     "aws-ec2-vpcblockpublicaccessexclusion.json",
@@ -1206,6 +1226,7 @@ cached: list[str] = [
     "aws-ecs-cluster.json",
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
+    "aws-ecs-service.json",
     "aws-ecs-taskdefinition.json",
     "aws-ecs-taskset.json",
     "aws-efs-accesspoint.json",
@@ -1268,6 +1289,7 @@ cached: list[str] = [
     "aws-fms-resourceset.json",
     "aws-fsx-datarepositoryassociation.json",
     "aws-fsx-filesystem.json",
+    "aws-fsx-s3accesspointattachment.json",
     "aws-fsx-snapshot.json",
     "aws-fsx-storagevirtualmachine.json",
     "aws-fsx-volume.json",
@@ -1364,6 +1386,7 @@ cached: list[str] = [
     "aws-iot-topicruledestination.json",
     "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
+    "aws-kinesis-streamconsumer.json",
     "aws-kinesisanalytics-applicationoutput.json",
     "aws-kinesisanalyticsv2-application.json",
     "aws-kinesisanalyticsv2-applicationoutput.json",
@@ -1389,6 +1412,7 @@ cached: list[str] = [
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
     "aws-lambda-url.json",
+    "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
     "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
@@ -1429,6 +1453,7 @@ cached: list[str] = [
     "aws-mwaa-environment.json",
     "aws-neptune-dbcluster.json",
     "aws-neptune-dbclusterparametergroup.json",
+    "aws-neptune-dbinstance.json",
     "aws-neptune-dbparametergroup.json",
     "aws-neptune-dbsubnetgroup.json",
     "aws-neptune-eventsubscription.json",
@@ -1437,6 +1462,7 @@ cached: list[str] = [
     "aws-networkfirewall-loggingconfiguration.json",
     "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
+    "aws-networkfirewall-vpcendpointassociation.json",
     "aws-networkmanager-customergatewayassociation.json",
     "aws-networkmanager-device.json",
     "aws-networkmanager-globalnetwork.json",
@@ -1453,6 +1479,7 @@ cached: list[str] = [
     "aws-opensearchserverless-securityconfig.json",
     "aws-opensearchserverless-securitypolicy.json",
     "aws-opensearchserverless-vpcendpoint.json",
+    "aws-opensearchservice-application.json",
     "aws-opensearchservice-domain.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
@@ -1503,6 +1530,7 @@ cached: list[str] = [
     "aws-redshift-integration.json",
     "aws-redshift-scheduledaction.json",
     "aws-redshiftserverless-namespace.json",
+    "aws-redshiftserverless-snapshot.json",
     "aws-redshiftserverless-workgroup.json",
     "aws-resiliencehub-app.json",
     "aws-resiliencehub-resiliencypolicy.json",
@@ -1528,12 +1556,10 @@ cached: list[str] = [
     "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
     "aws-route53resolver-outpostresolver.json",
-    "aws-route53resolver-resolverconfig.json",
     "aws-route53resolver-resolverdnssecconfig.json",
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
-    "aws-route53resolver-resolverruleassociation.json",
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
@@ -1541,17 +1567,21 @@ cached: list[str] = [
     "aws-s3-accesspoint.json",
     "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
+    "aws-s3-multiregionaccesspoint.json",
+    "aws-s3-multiregionaccesspointpolicy.json",
     "aws-s3objectlambda-accesspoint.json",
     "aws-s3objectlambda-accesspointpolicy.json",
     "aws-s3outposts-accesspoint.json",
     "aws-s3outposts-bucket.json",
     "aws-s3outposts-bucketpolicy.json",
     "aws-s3outposts-endpoint.json",
+    "aws-s3tables-namespace.json",
+    "aws-s3tables-tablebucket.json",
+    "aws-s3tables-tablebucketpolicy.json",
     "aws-sagemaker-app.json",
     "aws-sagemaker-appimageconfig.json",
     "aws-sagemaker-coderepository.json",
     "aws-sagemaker-dataqualityjobdefinition.json",
-    "aws-sagemaker-domain.json",
     "aws-sagemaker-endpointconfig.json",
     "aws-sagemaker-featuregroup.json",
     "aws-sagemaker-image.json",
@@ -1582,8 +1612,10 @@ cached: list[str] = [
     "aws-secretsmanager-secret.json",
     "aws-secretsmanager-secrettargetattachment.json",
     "aws-securityhub-automationrule.json",
+    "aws-securityhub-automationrulev2.json",
     "aws-securityhub-delegatedadmin.json",
     "aws-securityhub-hub.json",
+    "aws-securityhub-hubv2.json",
     "aws-securityhub-insight.json",
     "aws-securityhub-organizationconfiguration.json",
     "aws-securityhub-productsubscription.json",
@@ -1655,6 +1687,9 @@ cached: list[str] = [
     "aws-verifiedpermissions-policytemplate.json",
     "aws-vpclattice-accesslogsubscription.json",
     "aws-vpclattice-authpolicy.json",
+    "aws-vpclattice-listener.json",
+    "aws-vpclattice-resourceconfiguration.json",
+    "aws-vpclattice-resourcegateway.json",
     "aws-vpclattice-resourcepolicy.json",
     "aws-vpclattice-rule.json",
     "aws-vpclattice-service.json",
