@@ -45,6 +45,7 @@ types: list[str] = [
     "AWS::ApiGatewayV2::Model",
     "AWS::ApiGatewayV2::Route",
     "AWS::ApiGatewayV2::RouteResponse",
+    "AWS::ApiGatewayV2::RoutingRule",
     "AWS::ApiGatewayV2::Stage",
     "AWS::ApiGatewayV2::VpcLink",
     "AWS::AppConfig::Application",
@@ -85,7 +86,9 @@ types: list[str] = [
     "AWS::Backup::BackupPlan",
     "AWS::Backup::BackupSelection",
     "AWS::Backup::BackupVault",
+    "AWS::Backup::Framework",
     "AWS::Backup::LogicallyAirGappedBackupVault",
+    "AWS::Backup::ReportPlan",
     "AWS::Backup::RestoreTestingPlan",
     "AWS::Backup::RestoreTestingSelection",
     "AWS::Batch::ComputeEnvironment",
@@ -93,8 +96,13 @@ types: list[str] = [
     "AWS::Batch::JobDefinition",
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
+    "AWS::Bedrock::Flow",
+    "AWS::Bedrock::FlowAlias",
+    "AWS::Bedrock::FlowVersion",
     "AWS::Bedrock::Guardrail",
     "AWS::Bedrock::GuardrailVersion",
+    "AWS::Bedrock::Prompt",
+    "AWS::Bedrock::PromptVersion",
     "AWS::CDK::Metadata",
     "AWS::CE::AnomalyMonitor",
     "AWS::CE::AnomalySubscription",
@@ -121,8 +129,10 @@ types: list[str] = [
     "AWS::CloudFront::AnycastIpList",
     "AWS::CloudFront::CachePolicy",
     "AWS::CloudFront::CloudFrontOriginAccessIdentity",
+    "AWS::CloudFront::ConnectionGroup",
     "AWS::CloudFront::ContinuousDeploymentPolicy",
     "AWS::CloudFront::Distribution",
+    "AWS::CloudFront::DistributionTenant",
     "AWS::CloudFront::Function",
     "AWS::CloudFront::KeyGroup",
     "AWS::CloudFront::KeyValueStore",
@@ -291,6 +301,7 @@ types: list[str] = [
     "AWS::EC2::VolumeAttachment",
     "AWS::ECR::PullThroughCacheRule",
     "AWS::ECR::RegistryPolicy",
+    "AWS::ECR::RegistryScanningConfiguration",
     "AWS::ECR::ReplicationConfiguration",
     "AWS::ECR::Repository",
     "AWS::ECR::RepositoryCreationTemplate",
@@ -318,6 +329,7 @@ types: list[str] = [
     "AWS::EMR::Step",
     "AWS::EMRContainers::VirtualCluster",
     "AWS::ElastiCache::CacheCluster",
+    "AWS::ElastiCache::GlobalReplicationGroup",
     "AWS::ElastiCache::ParameterGroup",
     "AWS::ElastiCache::ReplicationGroup",
     "AWS::ElastiCache::SecurityGroup",
@@ -410,6 +422,8 @@ types: list[str] = [
     "AWS::ImageBuilder::InfrastructureConfiguration",
     "AWS::ImageBuilder::LifecyclePolicy",
     "AWS::ImageBuilder::Workflow",
+    "AWS::InspectorV2::CisScanConfiguration",
+    "AWS::InspectorV2::Filter",
     "AWS::InternetMonitor::Monitor",
     "AWS::IoT::Certificate",
     "AWS::IoT::Policy",
@@ -491,11 +505,13 @@ types: list[str] = [
     "AWS::NetworkFirewall::LoggingConfiguration",
     "AWS::NetworkFirewall::RuleGroup",
     "AWS::NetworkFirewall::TLSInspectionConfiguration",
+    "AWS::NetworkFirewall::VpcEndpointAssociation",
     "AWS::NetworkManager::ConnectAttachment",
     "AWS::NetworkManager::ConnectPeer",
     "AWS::NetworkManager::CoreNetwork",
     "AWS::NetworkManager::CustomerGatewayAssociation",
     "AWS::NetworkManager::Device",
+    "AWS::NetworkManager::DirectConnectGatewayAttachment",
     "AWS::NetworkManager::GlobalNetwork",
     "AWS::NetworkManager::Link",
     "AWS::NetworkManager::LinkAssociation",
@@ -507,6 +523,13 @@ types: list[str] = [
     "AWS::NetworkManager::VpcAttachment",
     "AWS::Oam::Link",
     "AWS::Oam::Sink",
+    "AWS::OpenSearchServerless::AccessPolicy",
+    "AWS::OpenSearchServerless::Collection",
+    "AWS::OpenSearchServerless::Index",
+    "AWS::OpenSearchServerless::LifecyclePolicy",
+    "AWS::OpenSearchServerless::SecurityConfig",
+    "AWS::OpenSearchServerless::SecurityPolicy",
+    "AWS::OpenSearchServerless::VpcEndpoint",
     "AWS::OpenSearchService::Domain",
     "AWS::OpsWorks::App",
     "AWS::OpsWorks::ElasticLoadBalancerAttachment",
@@ -556,6 +579,9 @@ types: list[str] = [
     "AWS::Redshift::EventSubscription",
     "AWS::Redshift::Integration",
     "AWS::Redshift::ScheduledAction",
+    "AWS::RedshiftServerless::Namespace",
+    "AWS::RedshiftServerless::Snapshot",
+    "AWS::RedshiftServerless::Workgroup",
     "AWS::ResourceExplorer2::DefaultViewAssociation",
     "AWS::ResourceExplorer2::Index",
     "AWS::ResourceExplorer2::View",
@@ -564,6 +590,7 @@ types: list[str] = [
     "AWS::RolesAnywhere::CRL",
     "AWS::RolesAnywhere::Profile",
     "AWS::RolesAnywhere::TrustAnchor",
+    "AWS::Route53::CidrCollection",
     "AWS::Route53::DNSSEC",
     "AWS::Route53::HealthCheck",
     "AWS::Route53::HostedZone",
@@ -589,8 +616,14 @@ types: list[str] = [
     "AWS::S3::AccessPoint",
     "AWS::S3::Bucket",
     "AWS::S3::BucketPolicy",
+    "AWS::S3::MultiRegionAccessPoint",
+    "AWS::S3::MultiRegionAccessPointPolicy",
     "AWS::S3ObjectLambda::AccessPoint",
     "AWS::S3ObjectLambda::AccessPointPolicy",
+    "AWS::S3Tables::Namespace",
+    "AWS::S3Tables::Table",
+    "AWS::S3Tables::TableBucket",
+    "AWS::S3Tables::TableBucketPolicy",
     "AWS::SDB::Domain",
     "AWS::SNS::Subscription",
     "AWS::SNS::Topic",
@@ -739,15 +772,18 @@ cached: list[str] = [
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
     "aws-apigateway-vpclink.json",
+    "aws-apigatewayv2-api.json",
     "aws-apigatewayv2-apigatewaymanagedoverrides.json",
     "aws-apigatewayv2-apimapping.json",
     "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
+    "aws-apigatewayv2-domainname.json",
     "aws-apigatewayv2-integration.json",
     "aws-apigatewayv2-integrationresponse.json",
     "aws-apigatewayv2-model.json",
     "aws-apigatewayv2-route.json",
     "aws-apigatewayv2-routeresponse.json",
+    "aws-apigatewayv2-routingrule.json",
     "aws-apigatewayv2-stage.json",
     "aws-apigatewayv2-vpclink.json",
     "aws-appconfig-application.json",
@@ -776,6 +812,7 @@ cached: list[str] = [
     "aws-appsync-sourceapiassociation.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
+    "aws-athena-datacatalog.json",
     "aws-athena-namedquery.json",
     "aws-athena-preparedstatement.json",
     "aws-athena-workgroup.json",
@@ -788,7 +825,9 @@ cached: list[str] = [
     "aws-backup-backupplan.json",
     "aws-backup-backupselection.json",
     "aws-backup-backupvault.json",
+    "aws-backup-framework.json",
     "aws-backup-logicallyairgappedbackupvault.json",
+    "aws-backup-reportplan.json",
     "aws-backup-restoretestingplan.json",
     "aws-backup-restoretestingselection.json",
     "aws-batch-computeenvironment.json",
@@ -796,11 +835,16 @@ cached: list[str] = [
     "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
+    "aws-bedrock-flow.json",
+    "aws-bedrock-flowalias.json",
+    "aws-bedrock-flowversion.json",
+    "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
+    "aws-bedrock-prompt.json",
+    "aws-bedrock-promptversion.json",
     "aws-ce-anomalymonitor.json",
     "aws-ce-anomalysubscription.json",
     "aws-certificatemanager-certificate.json",
-    "aws-chatbot-customaction.json",
     "aws-chatbot-microsoftteamschannelconfiguration.json",
     "aws-chatbot-slackchannelconfiguration.json",
     "aws-cloudformation-customresource.json",
@@ -821,8 +865,8 @@ cached: list[str] = [
     "aws-cloudfront-anycastiplist.json",
     "aws-cloudfront-cachepolicy.json",
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
+    "aws-cloudfront-connectiongroup.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
-    "aws-cloudfront-distribution.json",
     "aws-cloudfront-function.json",
     "aws-cloudfront-keygroup.json",
     "aws-cloudfront-keyvaluestore.json",
@@ -981,6 +1025,7 @@ cached: list[str] = [
     "aws-ec2-vpngatewayroutepropagation.json",
     "aws-ecr-pullthroughcacherule.json",
     "aws-ecr-registrypolicy.json",
+    "aws-ecr-registryscanningconfiguration.json",
     "aws-ecr-replicationconfiguration.json",
     "aws-ecr-repository.json",
     "aws-ecr-repositorycreationtemplate.json",
@@ -1002,6 +1047,7 @@ cached: list[str] = [
     "aws-eks-nodegroup.json",
     "aws-eks-podidentityassociation.json",
     "aws-elasticache-cachecluster.json",
+    "aws-elasticache-globalreplicationgroup.json",
     "aws-elasticache-parametergroup.json",
     "aws-elasticache-replicationgroup.json",
     "aws-elasticache-securitygroup.json",
@@ -1021,6 +1067,7 @@ cached: list[str] = [
     "aws-emr-cluster.json",
     "aws-emr-instancefleetconfig.json",
     "aws-emr-instancegroupconfig.json",
+    "aws-emr-securityconfiguration.json",
     "aws-emr-step.json",
     "aws-emrcontainers-virtualcluster.json",
     "aws-events-apidestination.json",
@@ -1090,11 +1137,14 @@ cached: list[str] = [
     "aws-imagebuilder-infrastructureconfiguration.json",
     "aws-imagebuilder-lifecyclepolicy.json",
     "aws-imagebuilder-workflow.json",
+    "aws-inspectorv2-cisscanconfiguration.json",
+    "aws-inspectorv2-filter.json",
     "aws-internetmonitor-monitor.json",
+    "aws-iot-thingprincipalattachment.json",
     "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
+    "aws-kinesis-streamconsumer.json",
     "aws-kinesisanalyticsv2-application.json",
-    "aws-kinesisfirehose-deliverystream.json",
     "aws-kms-alias.json",
     "aws-kms-key.json",
     "aws-kms-replicakey.json",
@@ -1110,8 +1160,8 @@ cached: list[str] = [
     "aws-lambda-eventsourcemapping.json",
     "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
-    "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
+    "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
     "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
@@ -1125,7 +1175,6 @@ cached: list[str] = [
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
     "aws-logs-subscriptionfilter.json",
-    "aws-logs-transformer.json",
     "aws-mediaconnect-flow.json",
     "aws-mediaconnect-flowentitlement.json",
     "aws-mediaconnect-flowoutput.json",
@@ -1163,11 +1212,13 @@ cached: list[str] = [
     "aws-networkfirewall-loggingconfiguration.json",
     "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
+    "aws-networkfirewall-vpcendpointassociation.json",
     "aws-networkmanager-connectattachment.json",
     "aws-networkmanager-connectpeer.json",
     "aws-networkmanager-corenetwork.json",
     "aws-networkmanager-customergatewayassociation.json",
     "aws-networkmanager-device.json",
+    "aws-networkmanager-directconnectgatewayattachment.json",
     "aws-networkmanager-globalnetwork.json",
     "aws-networkmanager-link.json",
     "aws-networkmanager-linkassociation.json",
@@ -1179,6 +1230,13 @@ cached: list[str] = [
     "aws-networkmanager-vpcattachment.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
+    "aws-opensearchserverless-accesspolicy.json",
+    "aws-opensearchserverless-collection.json",
+    "aws-opensearchserverless-index.json",
+    "aws-opensearchserverless-lifecyclepolicy.json",
+    "aws-opensearchserverless-securityconfig.json",
+    "aws-opensearchserverless-securitypolicy.json",
+    "aws-opensearchserverless-vpcendpoint.json",
     "aws-opensearchservice-domain.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
@@ -1200,7 +1258,9 @@ cached: list[str] = [
     "aws-ram-permission.json",
     "aws-ram-resourceshare.json",
     "aws-rbin-rule.json",
+    "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
+    "aws-rds-dbinstance.json",
     "aws-rds-dbparametergroup.json",
     "aws-rds-dbproxy.json",
     "aws-rds-dbproxyendpoint.json",
@@ -1222,6 +1282,9 @@ cached: list[str] = [
     "aws-redshift-eventsubscription.json",
     "aws-redshift-integration.json",
     "aws-redshift-scheduledaction.json",
+    "aws-redshiftserverless-namespace.json",
+    "aws-redshiftserverless-snapshot.json",
+    "aws-redshiftserverless-workgroup.json",
     "aws-resourceexplorer2-defaultviewassociation.json",
     "aws-resourceexplorer2-index.json",
     "aws-resourceexplorer2-view.json",
@@ -1230,6 +1293,7 @@ cached: list[str] = [
     "aws-rolesanywhere-crl.json",
     "aws-rolesanywhere-profile.json",
     "aws-rolesanywhere-trustanchor.json",
+    "aws-route53-cidrcollection.json",
     "aws-route53-dnssec.json",
     "aws-route53-hostedzone.json",
     "aws-route53-keysigningkey.json",
@@ -1241,13 +1305,10 @@ cached: list[str] = [
     "aws-route53resolver-firewalldomainlist.json",
     "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
-    "aws-route53resolver-resolverconfig.json",
     "aws-route53resolver-resolverdnssecconfig.json",
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
-    "aws-route53resolver-resolverrule.json",
-    "aws-route53resolver-resolverruleassociation.json",
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
@@ -1255,8 +1316,14 @@ cached: list[str] = [
     "aws-s3-accesspoint.json",
     "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
+    "aws-s3-multiregionaccesspoint.json",
+    "aws-s3-multiregionaccesspointpolicy.json",
     "aws-s3objectlambda-accesspoint.json",
     "aws-s3objectlambda-accesspointpolicy.json",
+    "aws-s3tables-namespace.json",
+    "aws-s3tables-table.json",
+    "aws-s3tables-tablebucket.json",
+    "aws-s3tables-tablebucketpolicy.json",
     "aws-sagemaker-mlflowtrackingserver.json",
     "aws-sagemaker-modelcard.json",
     "aws-scheduler-schedule.json",
@@ -1339,6 +1406,7 @@ cached: list[str] = [
     "aws-verifiedpermissions-policytemplate.json",
     "aws-vpclattice-accesslogsubscription.json",
     "aws-vpclattice-authpolicy.json",
+    "aws-vpclattice-listener.json",
     "aws-vpclattice-resourcepolicy.json",
     "aws-vpclattice-rule.json",
     "aws-vpclattice-service.json",
@@ -1351,6 +1419,8 @@ cached: list[str] = [
     "aws-wafv2-ipset.json",
     "aws-wafv2-loggingconfiguration.json",
     "aws-wafv2-regexpatternset.json",
+    "aws-wafv2-rulegroup.json",
+    "aws-wafv2-webacl.json",
     "aws-wafv2-webaclassociation.json",
     "aws-workspaces-workspace.json",
     "aws-xray-group.json",
