@@ -6,6 +6,7 @@ types: list[str] = [
     "AWS::ACMPCA::CertificateAuthority",
     "AWS::ACMPCA::CertificateAuthorityActivation",
     "AWS::ACMPCA::Permission",
+    "AWS::AIOps::InvestigationGroup",
     "AWS::APS::RuleGroupsNamespace",
     "AWS::APS::Scraper",
     "AWS::APS::Workspace",
@@ -54,6 +55,7 @@ types: list[str] = [
     "AWS::ApiGatewayV2::Model",
     "AWS::ApiGatewayV2::Route",
     "AWS::ApiGatewayV2::RouteResponse",
+    "AWS::ApiGatewayV2::RoutingRule",
     "AWS::ApiGatewayV2::Stage",
     "AWS::ApiGatewayV2::VpcLink",
     "AWS::AppConfig::Application",
@@ -116,11 +118,13 @@ types: list[str] = [
     "AWS::Batch::SchedulingPolicy",
     "AWS::Bedrock::Agent",
     "AWS::Bedrock::AgentAlias",
+    "AWS::Bedrock::DataSource",
     "AWS::Bedrock::Flow",
     "AWS::Bedrock::FlowAlias",
     "AWS::Bedrock::FlowVersion",
     "AWS::Bedrock::Guardrail",
     "AWS::Bedrock::GuardrailVersion",
+    "AWS::Bedrock::KnowledgeBase",
     "AWS::Bedrock::Prompt",
     "AWS::Bedrock::PromptVersion",
     "AWS::CDK::Metadata",
@@ -164,8 +168,10 @@ types: list[str] = [
     "AWS::CloudFront::AnycastIpList",
     "AWS::CloudFront::CachePolicy",
     "AWS::CloudFront::CloudFrontOriginAccessIdentity",
+    "AWS::CloudFront::ConnectionGroup",
     "AWS::CloudFront::ContinuousDeploymentPolicy",
     "AWS::CloudFront::Distribution",
+    "AWS::CloudFront::DistributionTenant",
     "AWS::CloudFront::Function",
     "AWS::CloudFront::KeyGroup",
     "AWS::CloudFront::KeyValueStore",
@@ -268,17 +274,20 @@ types: list[str] = [
     "AWS::DataSync::LocationObjectStorage",
     "AWS::DataSync::LocationS3",
     "AWS::DataSync::LocationSMB",
-    "AWS::DataSync::StorageSystem",
     "AWS::DataSync::Task",
+    "AWS::DataZone::Connection",
     "AWS::DataZone::DataSource",
     "AWS::DataZone::Domain",
+    "AWS::DataZone::DomainUnit",
     "AWS::DataZone::Environment",
     "AWS::DataZone::EnvironmentActions",
     "AWS::DataZone::EnvironmentBlueprintConfiguration",
     "AWS::DataZone::EnvironmentProfile",
     "AWS::DataZone::GroupProfile",
+    "AWS::DataZone::Owner",
     "AWS::DataZone::Project",
     "AWS::DataZone::ProjectMembership",
+    "AWS::DataZone::ProjectProfile",
     "AWS::DataZone::SubscriptionTarget",
     "AWS::DataZone::UserProfile",
     "AWS::Detective::Graph",
@@ -388,6 +397,7 @@ types: list[str] = [
     "AWS::EC2::VolumeAttachment",
     "AWS::ECR::PullThroughCacheRule",
     "AWS::ECR::RegistryPolicy",
+    "AWS::ECR::RegistryScanningConfiguration",
     "AWS::ECR::ReplicationConfiguration",
     "AWS::ECR::Repository",
     "AWS::ECR::RepositoryCreationTemplate",
@@ -464,6 +474,7 @@ types: list[str] = [
     "AWS::FMS::ResourceSet",
     "AWS::FSx::DataRepositoryAssociation",
     "AWS::FSx::FileSystem",
+    "AWS::FSx::S3AccessPointAttachment",
     "AWS::FSx::Snapshot",
     "AWS::FSx::StorageVirtualMachine",
     "AWS::FSx::Volume",
@@ -614,6 +625,7 @@ types: list[str] = [
     "AWS::Lightsail::Database",
     "AWS::Lightsail::Disk",
     "AWS::Lightsail::Instance",
+    "AWS::Lightsail::InstanceSnapshot",
     "AWS::Lightsail::LoadBalancer",
     "AWS::Lightsail::LoadBalancerTlsCertificate",
     "AWS::Lightsail::StaticIp",
@@ -713,6 +725,7 @@ types: list[str] = [
     "AWS::NetworkFirewall::LoggingConfiguration",
     "AWS::NetworkFirewall::RuleGroup",
     "AWS::NetworkFirewall::TLSInspectionConfiguration",
+    "AWS::NetworkFirewall::VpcEndpointAssociation",
     "AWS::NetworkManager::ConnectAttachment",
     "AWS::NetworkManager::ConnectPeer",
     "AWS::NetworkManager::CoreNetwork",
@@ -739,6 +752,7 @@ types: list[str] = [
     "AWS::OpenSearchServerless::SecurityConfig",
     "AWS::OpenSearchServerless::SecurityPolicy",
     "AWS::OpenSearchServerless::VpcEndpoint",
+    "AWS::OpenSearchService::Application",
     "AWS::OpenSearchService::Domain",
     "AWS::OpsWorks::App",
     "AWS::OpsWorks::ElasticLoadBalancerAttachment",
@@ -804,6 +818,7 @@ types: list[str] = [
     "AWS::Redshift::Integration",
     "AWS::Redshift::ScheduledAction",
     "AWS::RedshiftServerless::Namespace",
+    "AWS::RedshiftServerless::Snapshot",
     "AWS::RedshiftServerless::Workgroup",
     "AWS::RefactorSpaces::Application",
     "AWS::RefactorSpaces::Environment",
@@ -850,6 +865,7 @@ types: list[str] = [
     "AWS::S3::MultiRegionAccessPointPolicy",
     "AWS::S3::StorageLens",
     "AWS::S3::StorageLensGroup",
+    "AWS::S3Express::AccessPoint",
     "AWS::S3Express::BucketPolicy",
     "AWS::S3Express::DirectoryBucket",
     "AWS::S3ObjectLambda::AccessPoint",
@@ -858,6 +874,7 @@ types: list[str] = [
     "AWS::S3Outposts::Bucket",
     "AWS::S3Outposts::BucketPolicy",
     "AWS::S3Outposts::Endpoint",
+    "AWS::S3Tables::Namespace",
     "AWS::S3Tables::TableBucket",
     "AWS::S3Tables::TableBucketPolicy",
     "AWS::SDB::Domain",
@@ -868,6 +885,7 @@ types: list[str] = [
     "AWS::SES::EmailIdentity",
     "AWS::SES::MailManagerAddonInstance",
     "AWS::SES::MailManagerAddonSubscription",
+    "AWS::SES::MailManagerAddressList",
     "AWS::SES::MailManagerArchive",
     "AWS::SES::MailManagerIngressPoint",
     "AWS::SES::MailManagerRelay",
@@ -898,6 +916,7 @@ types: list[str] = [
     "AWS::SSMContacts::ContactChannel",
     "AWS::SSMContacts::Plan",
     "AWS::SSMContacts::Rotation",
+    "AWS::SSMGuiConnect::Preferences",
     "AWS::SSMIncidents::ReplicationSet",
     "AWS::SSMIncidents::ResponsePlan",
     "AWS::SSMQuickSetup::ConfigurationManager",
@@ -944,11 +963,14 @@ types: list[str] = [
     "AWS::SecretsManager::RotationSchedule",
     "AWS::SecretsManager::Secret",
     "AWS::SecretsManager::SecretTargetAttachment",
+    "AWS::SecurityHub::AggregatorV2",
     "AWS::SecurityHub::AutomationRule",
+    "AWS::SecurityHub::AutomationRuleV2",
     "AWS::SecurityHub::ConfigurationPolicy",
     "AWS::SecurityHub::DelegatedAdmin",
     "AWS::SecurityHub::FindingAggregator",
     "AWS::SecurityHub::Hub",
+    "AWS::SecurityHub::HubV2",
     "AWS::SecurityHub::Insight",
     "AWS::SecurityHub::OrganizationConfiguration",
     "AWS::SecurityHub::PolicyAssociation",
@@ -1064,6 +1086,7 @@ cached: list[str] = [
     "aws-acmpca-certificateauthority.json",
     "aws-acmpca-certificateauthorityactivation.json",
     "aws-acmpca-permission.json",
+    "aws-aiops-investigationgroup.json",
     "aws-amazonmq-broker.json",
     "aws-amazonmq-configuration.json",
     "aws-amplify-app.json",
@@ -1094,15 +1117,18 @@ cached: list[str] = [
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
     "aws-apigateway-vpclink.json",
+    "aws-apigatewayv2-api.json",
     "aws-apigatewayv2-apigatewaymanagedoverrides.json",
     "aws-apigatewayv2-apimapping.json",
     "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
+    "aws-apigatewayv2-domainname.json",
     "aws-apigatewayv2-integration.json",
     "aws-apigatewayv2-integrationresponse.json",
     "aws-apigatewayv2-model.json",
     "aws-apigatewayv2-route.json",
     "aws-apigatewayv2-routeresponse.json",
+    "aws-apigatewayv2-routingrule.json",
     "aws-apigatewayv2-stage.json",
     "aws-apigatewayv2-vpclink.json",
     "aws-appconfig-application.json",
@@ -1169,10 +1195,13 @@ cached: list[str] = [
     "aws-batch-schedulingpolicy.json",
     "aws-bedrock-agent.json",
     "aws-bedrock-agentalias.json",
+    "aws-bedrock-datasource.json",
     "aws-bedrock-flow.json",
     "aws-bedrock-flowalias.json",
     "aws-bedrock-flowversion.json",
+    "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
+    "aws-bedrock-knowledgebase.json",
     "aws-bedrock-prompt.json",
     "aws-bedrock-promptversion.json",
     "aws-cassandra-keyspace.json",
@@ -1183,7 +1212,6 @@ cached: list[str] = [
     "aws-ce-costcategory.json",
     "aws-certificatemanager-account.json",
     "aws-certificatemanager-certificate.json",
-    "aws-chatbot-customaction.json",
     "aws-chatbot-microsoftteamschannelconfiguration.json",
     "aws-chatbot-slackchannelconfiguration.json",
     "aws-cleanrooms-analysistemplate.json",
@@ -1215,8 +1243,9 @@ cached: list[str] = [
     "aws-cloudfront-anycastiplist.json",
     "aws-cloudfront-cachepolicy.json",
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
+    "aws-cloudfront-connectiongroup.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
-    "aws-cloudfront-distribution.json",
+    "aws-cloudfront-distributiontenant.json",
     "aws-cloudfront-function.json",
     "aws-cloudfront-keygroup.json",
     "aws-cloudfront-keyvaluestore.json",
@@ -1241,6 +1270,7 @@ cached: list[str] = [
     "aws-codeartifact-domain.json",
     "aws-codeartifact-packagegroup.json",
     "aws-codeartifact-repository.json",
+    "aws-codebuild-project.json",
     "aws-codebuild-reportgroup.json",
     "aws-codebuild-sourcecredential.json",
     "aws-codecommit-repository.json",
@@ -1304,17 +1334,20 @@ cached: list[str] = [
     "aws-datasync-locationobjectstorage.json",
     "aws-datasync-locations3.json",
     "aws-datasync-locationsmb.json",
-    "aws-datasync-storagesystem.json",
     "aws-datasync-task.json",
+    "aws-datazone-connection.json",
     "aws-datazone-datasource.json",
     "aws-datazone-domain.json",
+    "aws-datazone-domainunit.json",
     "aws-datazone-environment.json",
     "aws-datazone-environmentactions.json",
     "aws-datazone-environmentblueprintconfiguration.json",
     "aws-datazone-environmentprofile.json",
     "aws-datazone-groupprofile.json",
+    "aws-datazone-owner.json",
     "aws-datazone-project.json",
     "aws-datazone-projectmembership.json",
+    "aws-datazone-projectprofile.json",
     "aws-datazone-subscriptiontarget.json",
     "aws-datazone-userprofile.json",
     "aws-detective-graph.json",
@@ -1349,7 +1382,6 @@ cached: list[str] = [
     "aws-ec2-ec2fleet.json",
     "aws-ec2-egressonlyinternetgateway.json",
     "aws-ec2-eip.json",
-    "aws-ec2-eipassociation.json",
     "aws-ec2-enclavecertificateiamroleassociation.json",
     "aws-ec2-flowlog.json",
     "aws-ec2-gatewayroutetableassociation.json",
@@ -1435,6 +1467,7 @@ cached: list[str] = [
     "aws-ec2-vpngatewayroutepropagation.json",
     "aws-ecr-pullthroughcacherule.json",
     "aws-ecr-registrypolicy.json",
+    "aws-ecr-registryscanningconfiguration.json",
     "aws-ecr-replicationconfiguration.json",
     "aws-ecr-repository.json",
     "aws-ecr-repositorycreationtemplate.json",
@@ -1490,7 +1523,6 @@ cached: list[str] = [
     "aws-events-apidestination.json",
     "aws-events-archive.json",
     "aws-events-connection.json",
-    "aws-events-endpoint.json",
     "aws-events-eventbus.json",
     "aws-events-eventbuspolicy.json",
     "aws-events-rule.json",
@@ -1510,6 +1542,7 @@ cached: list[str] = [
     "aws-fms-resourceset.json",
     "aws-fsx-datarepositoryassociation.json",
     "aws-fsx-filesystem.json",
+    "aws-fsx-s3accesspointattachment.json",
     "aws-fsx-snapshot.json",
     "aws-fsx-storagevirtualmachine.json",
     "aws-fsx-volume.json",
@@ -1617,6 +1650,7 @@ cached: list[str] = [
     "aws-kafkaconnect-customplugin.json",
     "aws-kafkaconnect-workerconfiguration.json",
     "aws-kinesis-resourcepolicy.json",
+    "aws-kinesis-stream.json",
     "aws-kinesis-streamconsumer.json",
     "aws-kinesisanalytics-applicationoutput.json",
     "aws-kinesisanalyticsv2-application.json",
@@ -1641,6 +1675,7 @@ cached: list[str] = [
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
     "aws-lambda-url.json",
+    "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
     "aws-licensemanager-grant.json",
     "aws-licensemanager-license.json",
@@ -1651,6 +1686,7 @@ cached: list[str] = [
     "aws-lightsail-database.json",
     "aws-lightsail-disk.json",
     "aws-lightsail-instance.json",
+    "aws-lightsail-instancesnapshot.json",
     "aws-lightsail-loadbalancer.json",
     "aws-lightsail-loadbalancertlscertificate.json",
     "aws-lightsail-staticip.json",
@@ -1739,6 +1775,9 @@ cached: list[str] = [
     "aws-msk-vpcconnection.json",
     "aws-mwaa-environment.json",
     "aws-neptune-dbcluster.json",
+    "aws-neptune-dbclusterparametergroup.json",
+    "aws-neptune-dbinstance.json",
+    "aws-neptune-dbparametergroup.json",
     "aws-neptune-dbsubnetgroup.json",
     "aws-neptune-eventsubscription.json",
     "aws-networkfirewall-firewall.json",
@@ -1746,6 +1785,7 @@ cached: list[str] = [
     "aws-networkfirewall-loggingconfiguration.json",
     "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
+    "aws-networkfirewall-vpcendpointassociation.json",
     "aws-networkmanager-connectattachment.json",
     "aws-networkmanager-connectpeer.json",
     "aws-networkmanager-corenetwork.json",
@@ -1770,6 +1810,7 @@ cached: list[str] = [
     "aws-opensearchserverless-securityconfig.json",
     "aws-opensearchserverless-securitypolicy.json",
     "aws-opensearchserverless-vpcendpoint.json",
+    "aws-opensearchservice-application.json",
     "aws-opensearchservice-domain.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
@@ -1783,6 +1824,7 @@ cached: list[str] = [
     "aws-organizations-organizationalunit.json",
     "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
+    "aws-osis-pipeline.json",
     "aws-pcaconnectorad-connector.json",
     "aws-pcaconnectorad-directoryregistration.json",
     "aws-pcaconnectorad-serviceprincipalname.json",
@@ -1834,6 +1876,7 @@ cached: list[str] = [
     "aws-redshift-integration.json",
     "aws-redshift-scheduledaction.json",
     "aws-redshiftserverless-namespace.json",
+    "aws-redshiftserverless-snapshot.json",
     "aws-redshiftserverless-workgroup.json",
     "aws-refactorspaces-application.json",
     "aws-refactorspaces-environment.json",
@@ -1867,8 +1910,6 @@ cached: list[str] = [
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
-    "aws-route53resolver-resolverrule.json",
-    "aws-route53resolver-resolverruleassociation.json",
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
@@ -1880,6 +1921,7 @@ cached: list[str] = [
     "aws-s3-multiregionaccesspointpolicy.json",
     "aws-s3-storagelens.json",
     "aws-s3-storagelensgroup.json",
+    "aws-s3express-accesspoint.json",
     "aws-s3express-bucketpolicy.json",
     "aws-s3express-directorybucket.json",
     "aws-s3objectlambda-accesspoint.json",
@@ -1888,6 +1930,7 @@ cached: list[str] = [
     "aws-s3outposts-bucket.json",
     "aws-s3outposts-bucketpolicy.json",
     "aws-s3outposts-endpoint.json",
+    "aws-s3tables-namespace.json",
     "aws-s3tables-tablebucket.json",
     "aws-s3tables-tablebucketpolicy.json",
     "aws-sagemaker-app.json",
@@ -1927,11 +1970,14 @@ cached: list[str] = [
     "aws-secretsmanager-rotationschedule.json",
     "aws-secretsmanager-secret.json",
     "aws-secretsmanager-secrettargetattachment.json",
+    "aws-securityhub-aggregatorv2.json",
     "aws-securityhub-automationrule.json",
+    "aws-securityhub-automationrulev2.json",
     "aws-securityhub-configurationpolicy.json",
     "aws-securityhub-delegatedadmin.json",
     "aws-securityhub-findingaggregator.json",
     "aws-securityhub-hub.json",
+    "aws-securityhub-hubv2.json",
     "aws-securityhub-insight.json",
     "aws-securityhub-organizationconfiguration.json",
     "aws-securityhub-policyassociation.json",
@@ -1972,6 +2018,7 @@ cached: list[str] = [
     "aws-ses-emailidentity.json",
     "aws-ses-mailmanageraddoninstance.json",
     "aws-ses-mailmanageraddonsubscription.json",
+    "aws-ses-mailmanageraddresslist.json",
     "aws-ses-mailmanagerarchive.json",
     "aws-ses-mailmanageringresspoint.json",
     "aws-ses-mailmanagerrelay.json",
@@ -2009,6 +2056,7 @@ cached: list[str] = [
     "aws-ssmcontacts-contactchannel.json",
     "aws-ssmcontacts-plan.json",
     "aws-ssmcontacts-rotation.json",
+    "aws-ssmguiconnect-preferences.json",
     "aws-ssmincidents-replicationset.json",
     "aws-ssmincidents-responseplan.json",
     "aws-ssmquicksetup-configurationmanager.json",
@@ -2072,6 +2120,8 @@ cached: list[str] = [
     "aws-wafv2-ipset.json",
     "aws-wafv2-loggingconfiguration.json",
     "aws-wafv2-regexpatternset.json",
+    "aws-wafv2-rulegroup.json",
+    "aws-wafv2-webacl.json",
     "aws-wafv2-webaclassociation.json",
     "aws-workspaces-workspace.json",
     "aws-xray-group.json",
