@@ -54,6 +54,7 @@ types: list[str] = [
     "AWS::ApiGatewayV2::Model",
     "AWS::ApiGatewayV2::Route",
     "AWS::ApiGatewayV2::RouteResponse",
+    "AWS::ApiGatewayV2::RoutingRule",
     "AWS::ApiGatewayV2::Stage",
     "AWS::ApiGatewayV2::VpcLink",
     "AWS::AppConfig::Application",
@@ -79,7 +80,13 @@ types: list[str] = [
     "AWS::AppRunner::Service",
     "AWS::AppRunner::VpcConnector",
     "AWS::AppRunner::VpcIngressConnection",
+    "AWS::AppStream::AppBlock",
+    "AWS::AppStream::AppBlockBuilder",
+    "AWS::AppStream::Application",
+    "AWS::AppStream::ApplicationEntitlementAssociation",
+    "AWS::AppStream::ApplicationFleetAssociation",
     "AWS::AppStream::DirectoryConfig",
+    "AWS::AppStream::Entitlement",
     "AWS::AppStream::Fleet",
     "AWS::AppStream::ImageBuilder",
     "AWS::AppStream::Stack",
@@ -137,6 +144,7 @@ types: list[str] = [
     "AWS::Bedrock::FlowVersion",
     "AWS::Bedrock::Guardrail",
     "AWS::Bedrock::GuardrailVersion",
+    "AWS::Bedrock::IntelligentPromptRouter",
     "AWS::Bedrock::KnowledgeBase",
     "AWS::Bedrock::Prompt",
     "AWS::Bedrock::PromptVersion",
@@ -264,6 +272,7 @@ types: list[str] = [
     "AWS::DMS::ReplicationInstance",
     "AWS::DMS::ReplicationSubnetGroup",
     "AWS::DMS::ReplicationTask",
+    "AWS::DSQL::Cluster",
     "AWS::DataBrew::Dataset",
     "AWS::DataBrew::Job",
     "AWS::DataBrew::Project",
@@ -282,8 +291,22 @@ types: list[str] = [
     "AWS::DataSync::LocationObjectStorage",
     "AWS::DataSync::LocationS3",
     "AWS::DataSync::LocationSMB",
-    "AWS::DataSync::StorageSystem",
     "AWS::DataSync::Task",
+    "AWS::DataZone::Connection",
+    "AWS::DataZone::DataSource",
+    "AWS::DataZone::Domain",
+    "AWS::DataZone::DomainUnit",
+    "AWS::DataZone::Environment",
+    "AWS::DataZone::EnvironmentActions",
+    "AWS::DataZone::EnvironmentBlueprintConfiguration",
+    "AWS::DataZone::EnvironmentProfile",
+    "AWS::DataZone::GroupProfile",
+    "AWS::DataZone::Owner",
+    "AWS::DataZone::Project",
+    "AWS::DataZone::ProjectMembership",
+    "AWS::DataZone::ProjectProfile",
+    "AWS::DataZone::SubscriptionTarget",
+    "AWS::DataZone::UserProfile",
     "AWS::Detective::Graph",
     "AWS::Detective::MemberInvitation",
     "AWS::Detective::OrganizationAdmin",
@@ -609,6 +632,7 @@ types: list[str] = [
     "AWS::Lightsail::Database",
     "AWS::Lightsail::Disk",
     "AWS::Lightsail::Instance",
+    "AWS::Lightsail::InstanceSnapshot",
     "AWS::Lightsail::LoadBalancer",
     "AWS::Lightsail::LoadBalancerTlsCertificate",
     "AWS::Lightsail::StaticIp",
@@ -698,6 +722,7 @@ types: list[str] = [
     "AWS::NetworkFirewall::LoggingConfiguration",
     "AWS::NetworkFirewall::RuleGroup",
     "AWS::NetworkFirewall::TLSInspectionConfiguration",
+    "AWS::NetworkFirewall::VpcEndpointAssociation",
     "AWS::NetworkManager::ConnectAttachment",
     "AWS::NetworkManager::ConnectPeer",
     "AWS::NetworkManager::CoreNetwork",
@@ -783,6 +808,7 @@ types: list[str] = [
     "AWS::Redshift::Integration",
     "AWS::Redshift::ScheduledAction",
     "AWS::RedshiftServerless::Namespace",
+    "AWS::RedshiftServerless::Snapshot",
     "AWS::RedshiftServerless::Workgroup",
     "AWS::RefactorSpaces::Application",
     "AWS::RefactorSpaces::Environment",
@@ -835,6 +861,8 @@ types: list[str] = [
     "AWS::S3Outposts::Bucket",
     "AWS::S3Outposts::BucketPolicy",
     "AWS::S3Outposts::Endpoint",
+    "AWS::S3Tables::Namespace",
+    "AWS::S3Tables::Table",
     "AWS::S3Tables::TableBucket",
     "AWS::S3Tables::TableBucketPolicy",
     "AWS::SDB::Domain",
@@ -845,6 +873,7 @@ types: list[str] = [
     "AWS::SES::EmailIdentity",
     "AWS::SES::MailManagerAddonInstance",
     "AWS::SES::MailManagerAddonSubscription",
+    "AWS::SES::MailManagerAddressList",
     "AWS::SES::MailManagerArchive",
     "AWS::SES::MailManagerIngressPoint",
     "AWS::SES::MailManagerRelay",
@@ -920,11 +949,14 @@ types: list[str] = [
     "AWS::SecretsManager::RotationSchedule",
     "AWS::SecretsManager::Secret",
     "AWS::SecretsManager::SecretTargetAttachment",
+    "AWS::SecurityHub::AggregatorV2",
     "AWS::SecurityHub::AutomationRule",
+    "AWS::SecurityHub::AutomationRuleV2",
     "AWS::SecurityHub::ConfigurationPolicy",
     "AWS::SecurityHub::DelegatedAdmin",
     "AWS::SecurityHub::FindingAggregator",
     "AWS::SecurityHub::Hub",
+    "AWS::SecurityHub::HubV2",
     "AWS::SecurityHub::Insight",
     "AWS::SecurityHub::OrganizationConfiguration",
     "AWS::SecurityHub::PolicyAssociation",
@@ -1024,6 +1056,9 @@ types: list[str] = [
     "AWS::WAFv2::WebACL",
     "AWS::WAFv2::WebACLAssociation",
     "AWS::WorkSpaces::Workspace",
+    "AWS::WorkspacesInstances::Volume",
+    "AWS::WorkspacesInstances::VolumeAssociation",
+    "AWS::WorkspacesInstances::WorkspaceInstance",
     "AWS::XRay::Group",
     "AWS::XRay::ResourcePolicy",
     "AWS::XRay::SamplingRule",
@@ -1083,6 +1118,7 @@ cached: list[str] = [
     "aws-apigatewayv2-model.json",
     "aws-apigatewayv2-route.json",
     "aws-apigatewayv2-routeresponse.json",
+    "aws-apigatewayv2-routingrule.json",
     "aws-apigatewayv2-stage.json",
     "aws-apigatewayv2-vpclink.json",
     "aws-appconfig-application.json",
@@ -1113,6 +1149,12 @@ cached: list[str] = [
     "aws-apprunner-service.json",
     "aws-apprunner-vpcconnector.json",
     "aws-apprunner-vpcingressconnection.json",
+    "aws-appstream-appblock.json",
+    "aws-appstream-appblockbuilder.json",
+    "aws-appstream-application.json",
+    "aws-appstream-applicationentitlementassociation.json",
+    "aws-appstream-applicationfleetassociation.json",
+    "aws-appstream-entitlement.json",
     "aws-appstream-fleet.json",
     "aws-appstream-stack.json",
     "aws-appstream-stackfleetassociation.json",
@@ -1165,9 +1207,11 @@ cached: list[str] = [
     "aws-bedrock-flowversion.json",
     "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
+    "aws-bedrock-intelligentpromptrouter.json",
     "aws-bedrock-knowledgebase.json",
     "aws-bedrock-prompt.json",
     "aws-bedrock-promptversion.json",
+    "aws-budgets-budget.json",
     "aws-budgets-budgetsaction.json",
     "aws-cassandra-keyspace.json",
     "aws-cassandra-table.json",
@@ -1203,7 +1247,6 @@ cached: list[str] = [
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
     "aws-cloudfront-connectiongroup.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
-    "aws-cloudfront-distribution.json",
     "aws-cloudfront-distributiontenant.json",
     "aws-cloudfront-function.json",
     "aws-cloudfront-keygroup.json",
@@ -1291,8 +1334,22 @@ cached: list[str] = [
     "aws-datasync-locationobjectstorage.json",
     "aws-datasync-locations3.json",
     "aws-datasync-locationsmb.json",
-    "aws-datasync-storagesystem.json",
     "aws-datasync-task.json",
+    "aws-datazone-connection.json",
+    "aws-datazone-datasource.json",
+    "aws-datazone-domain.json",
+    "aws-datazone-domainunit.json",
+    "aws-datazone-environment.json",
+    "aws-datazone-environmentactions.json",
+    "aws-datazone-environmentblueprintconfiguration.json",
+    "aws-datazone-environmentprofile.json",
+    "aws-datazone-groupprofile.json",
+    "aws-datazone-owner.json",
+    "aws-datazone-project.json",
+    "aws-datazone-projectmembership.json",
+    "aws-datazone-projectprofile.json",
+    "aws-datazone-subscriptiontarget.json",
+    "aws-datazone-userprofile.json",
     "aws-dax-cluster.json",
     "aws-dax-parametergroup.json",
     "aws-dax-subnetgroup.json",
@@ -1320,6 +1377,7 @@ cached: list[str] = [
     "aws-docdb-dbsubnetgroup.json",
     "aws-docdb-eventsubscription.json",
     "aws-docdbelastic-cluster.json",
+    "aws-dsql-cluster.json",
     "aws-dynamodb-globaltable.json",
     "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
@@ -1359,7 +1417,6 @@ cached: list[str] = [
     "aws-ec2-networkaclentry.json",
     "aws-ec2-networkinsightsaccessscope.json",
     "aws-ec2-networkinsightsaccessscopeanalysis.json",
-    "aws-ec2-networkinsightsanalysis.json",
     "aws-ec2-networkinsightspath.json",
     "aws-ec2-networkinterface.json",
     "aws-ec2-networkinterfaceattachment.json",
@@ -1396,6 +1453,7 @@ cached: list[str] = [
     "aws-ec2-transitgatewayroutetableassociation.json",
     "aws-ec2-transitgatewayroutetablepropagation.json",
     "aws-ec2-transitgatewayvpcattachment.json",
+    "aws-ec2-volume.json",
     "aws-ec2-volumeattachment.json",
     "aws-ec2-vpc.json",
     "aws-ec2-vpcblockpublicaccessexclusion.json",
@@ -1422,6 +1480,7 @@ cached: list[str] = [
     "aws-ecs-cluster.json",
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
+    "aws-ecs-service.json",
     "aws-ecs-taskdefinition.json",
     "aws-ecs-taskset.json",
     "aws-efs-accesspoint.json",
@@ -1469,7 +1528,6 @@ cached: list[str] = [
     "aws-events-apidestination.json",
     "aws-events-archive.json",
     "aws-events-connection.json",
-    "aws-events-endpoint.json",
     "aws-events-eventbus.json",
     "aws-events-eventbuspolicy.json",
     "aws-events-rule.json",
@@ -1610,6 +1668,7 @@ cached: list[str] = [
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
     "aws-lambda-url.json",
+    "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
     "aws-licensemanager-grant.json",
     "aws-licensemanager-license.json",
@@ -1620,11 +1679,13 @@ cached: list[str] = [
     "aws-lightsail-database.json",
     "aws-lightsail-disk.json",
     "aws-lightsail-instance.json",
+    "aws-lightsail-instancesnapshot.json",
     "aws-lightsail-loadbalancer.json",
     "aws-lightsail-loadbalancertlscertificate.json",
     "aws-lightsail-staticip.json",
     "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
+    "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
     "aws-logs-integration.json",
@@ -1699,6 +1760,7 @@ cached: list[str] = [
     "aws-mwaa-environment.json",
     "aws-neptune-dbcluster.json",
     "aws-neptune-dbclusterparametergroup.json",
+    "aws-neptune-dbinstance.json",
     "aws-neptune-dbparametergroup.json",
     "aws-neptune-dbsubnetgroup.json",
     "aws-neptune-eventsubscription.json",
@@ -1707,6 +1769,7 @@ cached: list[str] = [
     "aws-networkfirewall-loggingconfiguration.json",
     "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
+    "aws-networkfirewall-vpcendpointassociation.json",
     "aws-networkmanager-connectattachment.json",
     "aws-networkmanager-connectpeer.json",
     "aws-networkmanager-corenetwork.json",
@@ -1791,6 +1854,7 @@ cached: list[str] = [
     "aws-redshift-integration.json",
     "aws-redshift-scheduledaction.json",
     "aws-redshiftserverless-namespace.json",
+    "aws-redshiftserverless-snapshot.json",
     "aws-redshiftserverless-workgroup.json",
     "aws-refactorspaces-application.json",
     "aws-refactorspaces-environment.json",
@@ -1820,12 +1884,10 @@ cached: list[str] = [
     "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
     "aws-route53resolver-outpostresolver.json",
-    "aws-route53resolver-resolverconfig.json",
     "aws-route53resolver-resolverdnssecconfig.json",
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
-    "aws-route53resolver-resolverruleassociation.json",
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
@@ -1843,6 +1905,8 @@ cached: list[str] = [
     "aws-s3outposts-bucket.json",
     "aws-s3outposts-bucketpolicy.json",
     "aws-s3outposts-endpoint.json",
+    "aws-s3tables-namespace.json",
+    "aws-s3tables-table.json",
     "aws-s3tables-tablebucket.json",
     "aws-s3tables-tablebucketpolicy.json",
     "aws-sagemaker-app.json",
@@ -1880,11 +1944,14 @@ cached: list[str] = [
     "aws-secretsmanager-rotationschedule.json",
     "aws-secretsmanager-secret.json",
     "aws-secretsmanager-secrettargetattachment.json",
+    "aws-securityhub-aggregatorv2.json",
     "aws-securityhub-automationrule.json",
+    "aws-securityhub-automationrulev2.json",
     "aws-securityhub-configurationpolicy.json",
     "aws-securityhub-delegatedadmin.json",
     "aws-securityhub-findingaggregator.json",
     "aws-securityhub-hub.json",
+    "aws-securityhub-hubv2.json",
     "aws-securityhub-insight.json",
     "aws-securityhub-organizationconfiguration.json",
     "aws-securityhub-policyassociation.json",
@@ -1927,6 +1994,7 @@ cached: list[str] = [
     "aws-ses-emailidentity.json",
     "aws-ses-mailmanageraddoninstance.json",
     "aws-ses-mailmanageraddonsubscription.json",
+    "aws-ses-mailmanageraddresslist.json",
     "aws-ses-mailmanagerarchive.json",
     "aws-ses-mailmanageringresspoint.json",
     "aws-ses-mailmanagerrelay.json",
@@ -1995,6 +2063,9 @@ cached: list[str] = [
     "aws-verifiedpermissions-policytemplate.json",
     "aws-vpclattice-accesslogsubscription.json",
     "aws-vpclattice-authpolicy.json",
+    "aws-vpclattice-listener.json",
+    "aws-vpclattice-resourceconfiguration.json",
+    "aws-vpclattice-resourcegateway.json",
     "aws-vpclattice-resourcepolicy.json",
     "aws-vpclattice-rule.json",
     "aws-vpclattice-service.json",
@@ -2022,6 +2093,9 @@ cached: list[str] = [
     "aws-wafv2-webacl.json",
     "aws-wafv2-webaclassociation.json",
     "aws-workspaces-workspace.json",
+    "aws-workspacesinstances-volume.json",
+    "aws-workspacesinstances-volumeassociation.json",
+    "aws-workspacesinstances-workspaceinstance.json",
     "aws-xray-group.json",
     "aws-xray-resourcepolicy.json",
     "aws-xray-samplingrule.json",
