@@ -29,32 +29,10 @@ class GetAtt(BaseFn):
     tags = ["functions", "getatt"]
 
     def __init__(self) -> None:
-        super().__init__("Fn::GetAtt", all_types)
-
-    def schema(self, validator, instance) -> dict[str, Any]:
-        resource_functions = []
-        if validator.context.transforms.has_language_extensions_transform():
-            resource_functions = ["Ref"]
-
-        return {
-            "type": ["string", "array"],
-            "minItems": 2,
-            "maxItems": 2,
-            "fn_items": [
-                {
-                    "functions": resource_functions,
-                    "schema": {
-                        "type": ["string"],
-                    },
-                },
-                {
-                    "functions": ["Ref"],
-                    "schema": {
-                        "type": ["string"],
-                    },
-                },
-            ],
-        }
+        super().__init__(
+            "Fn::GetAtt",
+            all_types,
+        )
 
     def _resolve_getatt(
         self,
@@ -173,7 +151,7 @@ class GetAtt(BaseFn):
 
         errs = list(
             self._resolve_getatt(
-                self.validator(validator), key, value, instance, s, paths
+                self.validator(validator, schema), key, value, instance, s, paths
             )
         )
         if errs:
