@@ -17,7 +17,7 @@ import sys
 import zipfile
 from copy import copy
 from functools import lru_cache
-from typing import Any, Dict, Iterator, Sequence
+from typing import TYPE_CHECKING, Any, Dict, Iterator, Sequence
 
 import jsonpatch
 import jsonpointer
@@ -33,7 +33,9 @@ from cfnlint.helpers import (
 from cfnlint.schema._exceptions import ResourceNotFoundError
 from cfnlint.schema._getatts import AttributeDict
 from cfnlint.schema._schema import Schema
-from cfnlint.schema.patch import SchemaPatch
+
+if TYPE_CHECKING:
+    from cfnlint.schema._patch import SchemaPatch
 
 LOGGER = logging.getLogger(__name__)
 
@@ -282,6 +284,32 @@ class ProviderSchemaManager:
 
         multiprocessing_logger.debug("Downloading template %s into %s", url, directory)
 
+        if "iso" in region:
+            all_types = ["AWS::CDK::Metadata", "Module"]
+            cached = ["Module"]
+            filenames = [
+                f
+                for f in os.listdir(directory_pr)
+                if os.path.isfile(os.path.join(directory_pr, f)) and f != "__init__.py"
+            ]
+            for filename in filenames:
+                with open(f"{directory_pr}{filename}", "r+", encoding="utf-8") as fh:
+                    spec = json.load(fh)
+                    all_types.append(spec["typeName"])
+                cached.append(filename)
+
+            with open(f"{directory}__init__.py", encoding="utf-8", mode="w") as f:
+                f.write("from __future__ import annotations\n\n")
+                f.write("# pylint: disable=too-many-lines\ntypes: list[str] = [\n")
+                for rt in sorted(all_types):
+                    f.write(f'    "{rt}",\n')
+                f.write(
+                    "]\n\n# pylint: disable=too-many-lines\ncached: list[str] = [\n"
+                )
+                for cache_file in sorted(cached):
+                    f.write(f'    "{cache_file}",\n')
+                f.write("]\n")
+
         # Check to see if we already have the latest version, and if so stop
         if not (url_has_newer_version(url) or force):
             return
@@ -320,31 +348,8 @@ class ProviderSchemaManager:
                 with open(f"{directory}{filename}", "r+", encoding="utf-8") as fh:
                     spec = json.load(fh)
                     all_types.append(spec["typeName"])
-                    try:
-                        spec = self._remove_descriptions(spec)
-                        spec = self._patch_provider_schema(spec, filename, "all")
-                        spec = self._patch_provider_schema(
-                            spec, filename, region=reg.py
-                        )
-                    except Exception as e:  # pylint: disable=broad-except
-                        LOGGER.info(
-                            "Issuing patching schema for %s in %s: %s",
-                            filename,
-                            reg.name,
-                            e,
-                        )
-                    # Back to zero to write spec
-                    fh.seek(0)
-                    json.dump(
-                        spec,
-                        fh,
-                        indent=1,
-                        separators=(",", ": "),
-                        sort_keys=True,
-                    )
-                    fh.write("\n")
-                    # Resize doc as needed
-                    fh.truncate()
+
+            self._patch_region_schemas(region)
 
             # if the region is not us-east-1 compare the files to those in us-east-1
             # symlink if the files are the same
@@ -392,6 +397,62 @@ class ProviderSchemaManager:
         except Exception as e:  # pylint: disable=broad-except
             LOGGER.info("Issuing updating schemas for %s: %s", region, e)
 
+    def patch_schemas(self) -> None:
+
+        self._patch_region_schemas(self._region_primary.name)
+        # pylint: disable=not-context-manager
+        with multiprocessing.Pool() as pool:
+            # Patch from registry schema
+            provider_pool_tuple = [
+                (k,) for k in REGIONS if k != self._region_primary.name
+            ]
+            pool.starmap(self._patch_region_schemas, provider_pool_tuple)
+
+    def _patch_region_schemas(self, region: str) -> None:
+        reg = ToPy(region)
+        directory = os.path.join(f"{self._root.path_relative}/{reg.py}/")
+
+        filenames = [
+            f
+            for f in os.listdir(directory)
+            if os.path.isfile(os.path.join(directory, f)) and f != "__init__.py"
+        ]
+
+        for filename in filenames:
+            with open(f"{directory}{filename}", "r+", encoding="utf-8") as fh:
+                spec = json.load(fh)
+                try:
+                    if "handlers" in spec:
+                        del spec["handlers"]
+                    if "tagging" in spec and "permissions" in spec.get("tagging", {}):
+                        del spec["tagging"]["permissions"]
+                        # tagging = spec.get("tagging", {})
+                        # if "permissions" in tagging:
+                        #    del tagging["permissions"]
+                        #    spec["tagging"] = tagging
+                    spec = self._remove_descriptions(spec)
+                    spec = self._patch_provider_schema(spec, filename, "all")
+                    spec = self._patch_provider_schema(spec, filename, region=reg.py)
+                except Exception as e:  # pylint: disable=broad-except
+                    LOGGER.info(
+                        "Issuing patching schema for %s in %s: %s",
+                        filename,
+                        reg.name,
+                        e,
+                    )
+                # Back to zero to write spec
+                fh.seek(0)
+                json.dump(
+                    spec,
+                    fh,
+                    indent=1,
+                    separators=(",", ": "),
+                    sort_keys=True,
+                )
+                fh.write("\n")
+                # Resize doc as needed
+                fh.truncate()
+
     def _patch_provider_schema(
         self, content: Dict, source_filename: str, region: str
     ) -> Dict:
@@ -456,33 +517,7 @@ class ProviderSchemaManager:
 
         return content
 
-    def patch(self, filename: str, regions: Sequence[str]):
-        try:
-            with open(filename, encoding="utf-8") as fp:
-                custom_spec_data = json.load(fp)
-                schema_patch = SchemaPatch.from_dict(custom_spec_data)
-                for region in regions:
-                    self._patch(schema_patch, region)
-        except IOError as e:
-            if e.errno == 2:
-                LOGGER.error("Override spec file not found: %s", filename)
-                sys.exit(1)
-            elif e.errno == 21:
-                LOGGER.error(
-                    "Override spec file references a directory, not a file: %s",
-                    filename,
-                )
-                sys.exit(1)
-            elif e.errno == 13:
-                LOGGER.error(
-                    "Permission denied when accessing override spec file: %s", filename
-                )
-                sys.exit(1)
-        except ValueError as err:
-            LOGGER.error("Override spec file %s is malformed: %s", filename, err)
-            sys.exit(1)
-
-    def _patch(self, patch: SchemaPatch, region: str) -> None:
+    def patch(self, patch: SchemaPatch, region: str) -> None:
         """Patch the schemas as needed
 
         Args:
@@ -528,7 +563,11 @@ class ProviderSchemaManager:
             except ResourceNotFoundError:
                 # Resource type doesn't exist in this region
                 continue
-            schema.patch(patches=patches)
+            try:
+                schema.patch(patches=patches)
+            except Exception as e:
+                print(f"Error applying patch {patches} for {resource_type}: {e}")
+                sys.exit(1)
 
     @lru_cache(maxsize=None)
     def get_type_getatts(self, resource_type: str, region: str) -> AttributeDict:
@@ -545,5 +584,20 @@ class ProviderSchemaManager:
         self.get_resource_schema(region=region, resource_type=resource_type)
         return self._schemas[region][resource_type].get_atts
 
+    @lru_cache(maxsize=None)
+    def get_type_ref(self, resource_type: str, region: str) -> dict[str, Any]:
+        """Get the Ref information for a type in a region
+
+        Args:
+            resource_type: The type of the resource. Example: AWS::S3::Bucket
+            region: The region to load the resource type from
+        Returns:
+            dict(str, Any): Returns a Dict where the keys are the attributes and the
+                value is the CloudFormation schema description of the attribute
+        """
+        resource_type = self._normalize_resource_type(resource_type)
+        self.get_resource_schema(region=region, resource_type=resource_type)
+        return self._schemas[region][resource_type].ref
+
 
 PROVIDER_SCHEMA_MANAGER: ProviderSchemaManager = ProviderSchemaManager()
